@@ -2,8 +2,8 @@
 
 _package_data = dict(
     full_package_name='ruamel.std.pathlib',
-    version_info=(0, 8, 0),
-    __version__='0.8.0',
+    version_info=(0, 9, 0),
+    __version__='0.9.0',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     since=2013,
@@ -12,6 +12,7 @@ _package_data = dict(
     license='MIT License',
     universal=True,
     tox=dict(env='*',),
+    python_requires='>=3.6',
     print_allowed=True,
 )
 # pathlib2 for 3.4 -> expanduser added
@@ -24,10 +25,30 @@ __version__ = _package_data['__version__']
 import os       # NOQA
 import sys      # NOQA
 import inspect  # NOQA
+import pathlib  # NOQA
 
 from pathlib import *  # NOQA
 
 
+# https://bugs.python.org/issue24132#msg401946
+# without this you cannot subclass or assign data attributes (methods always worked fine)
+class Path(type(pathlib.Path())):
+    def utime_ns(self, atime_ns, mtime_ns):
+        os.utime(self, ns=(atime_ns, mtime_ns), follow_symlinks=False)
+
+    def read_bytes_atime_preserve(self, *arg, **kw):
+        stat = os.stat(self)
+        res = self.read_bytes(*arg, **kw)
+        os.utime(self, ns=(stat.st_atime_ns, stat.st_mtime_ns), follow_symlinks=False)
+        return res
+
+    def read_text_atime_preserve(self, *arg, **kw):
+        stat = os.stat(self)
+        res = self.read_text(*arg, **kw)
+        os.utime(self, ns=(stat.st_atime_ns, stat.st_mtime_ns), follow_symlinks=False)
+        return res
+
+
 if sys.version_info < (3, 9):
 
     def _is_relative_to(self, other):
@@ -65,7 +86,7 @@ def popd():
 
 
 # just for some sanity
-Path.remove = Path.unlink
+pathlib.Path.remove = pathlib.Path.unlink
 
 
 def _rmtree(self):
@@ -101,7 +122,7 @@ def _hash(self, typ=None, size=-1):
     return h
 
 
-Path.hash = _hash
+pathlib.Path.hash = _hash
 
 
 def _copy(self, target):
@@ -111,15 +132,19 @@ def _copy(self, target):
     shutil.copy(str(self), str(target))
 
 
-Path.copy = _copy
+pathlib.Path.copy = _copy
 
 
 # this is the times parameter of os.utime, taking int/float seconds (and not nanoseconds)
-def _utime(self, atime, mtime):
-    os.utime(str(self), (atime, mtime), follow_symlinks=False)
+if sys.version_info < (3, 6):
+    def _utime(self, atime, mtime):
+        os.utime(str(self), (atime, mtime), follow_symlinks=False)
+else:
+    def _utime(self, atime, mtime):
+        os.utime(self, (atime, mtime), follow_symlinks=False)
 
 
-Path.utime = _utime
+pathlib.Path.utime = _utime
 
 
 # #
